@@ -1,4 +1,12 @@
 ﻿/// <reference path="jquery-1.7.1.js" />
+/* All content on this website (including text, images, source
+ * code and any other original works), unless otherwise noted,
+ * is licensed under a Creative Commons License.
+ *
+ * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
+ * Copyright (C) 2016-2020 OX Software GmbH
+ */
 
 var userid;
 var username;
@@ -22,8 +30,8 @@ try {// Load root from config file.  Error if missing or unable to determine api
 }
 
 var language = getURLParameter('lang');
-templid = getURLParameter("templid");
-if (templid == null) {   // If no template ID, see if we have a default from config.js
+templid = parseInt(getURLParameter("templid"));
+if (templid == null || isNaN(parseInt(templid))) {   // If no clean template ID, see if we have a default from config.js
 	try {
 		if (typeof(getDefaultTemplateId) == 'function') {
 			templid = getDefaultTemplateId ();
@@ -59,33 +67,34 @@ $().ready(function () {// Once ready, load templates.
         if (itemid === null) {
             $('#loginHeader').text(i18n.t('Please provide your credentials'));
         }
-    });
-
-    $.get('./l10n/languages', function (languages) {
-        var selectedLanguage = getURLParameter('lang');
-        if (selectedLanguage === null) {
-            selectedLanguage = "en_US";
-        }
-        $.each(languages, function (c, n) {
-            if (c === selectedLanguage) {
-                $('#languageSelect').append('<li class="active"><a href="#" language="' + c + '">' + n + '</a></li>');
-                $('#languageSelectButton').html(n + ' <span class="caret"></span>');
-            } else {
-                $('#languageSelect').append('<li><a href="#" language="' + c + '">' + n + '</a></li>');
+    })
+    .done(function () {
+        $.get('./l10n/languages', function (languages) {
+            var selectedLanguage = getURLParameter('lang');
+            if (selectedLanguage === null) {
+                selectedLanguage = "en_US";
             }
-        });
+            $.each(languages, function (c, n) {
+                if (c === selectedLanguage) {
+                    $('#languageSelect').append('<li class="active"><a href="#" language="' + c + '">' + n + '</a></li>');
+                    $('#languageSelectButton').html(n + ' <span class="caret"></span>');
+                } else {
+                    $('#languageSelect').append('<li><a href="#" language="' + c + '">' + n + '</a></li>');
+                }
+            });
 
-        var user = getURLParameter('user');
-        if (user !== null) {
-            $('#Username').val(user);
-            $('#Username').hide();
-            $('#loginHeader').text(i18n.t('Please provide your encryption password'));
-            $('#Password').focus();
-        }
-    }, 'json');
+            var user = getURLParameter('user');
+            if (user !== null) {
+                $('#Username').val(user);
+                $('#Username').hide();
+                $('#loginHeader').text(i18n.t('Please provide your encryption password'));
+                $('#Password').focus();
+            }
+        }, 'json');
 
-    // Language selection listener
-    $("#languageSelect").click(loadLanguage);
+        // Language selection listener
+        $("#languageSelect").click(loadLanguage);
+    });
 });
 
 function loadLanguage (ev) {
@@ -445,8 +454,11 @@ function openreader(ldata, extra) {
             if (ccList.length > 2) {
                 $('#cclist').html('<td class="tdname">' + i18n.t("Cc") +'</td><td><span class=\"oxlabelcontent\">' + prepHTML(ccList) + '</span></td>').show();
             }
+            var fromTd = $('<td>');
 
-            $('#fromlist').html('<td class="tdname">' + i18n.t("From") +'</td><td><span class=\"oxlabelcontent\">' + prepHTML(getFrom(data)) + '</span></td>');
+            fromTd.append(getSignature(data));
+            fromTd.append('<span class=\"oxlabelcontent\">' + prepHTML(getFrom(data)) + '</span>');
+            $('#fromlist').html('<td class="tdname">' + i18n.t("From") +'</td>').append(fromTd);
             $('#subject').text(getSubject(data));
             $('#attdiv').remove();
             var readercont = $('#reader').contents().find('html');
@@ -455,16 +467,16 @@ function openreader(ldata, extra) {
             $('#header').after(getAttachments(data, itemid, auth));
             $('#decoding').hide();
             $('#reply').unbind().click(function() {
-                reply(data);
+                reply(data, itemid);
             });
             $('#replyall').unbind().click(function() {
-                replyall(data);
+                replyall(data, itemid);
             });
             $('#reply-bottom').unbind().click(function() {
-                    reply(data);
+                    reply(data, itemid);
             });
             $('#replyall-bottom').unbind().click(function() {
-                    replyall(data);
+                    replyall(data, itemid);
             });
             // Some squeeze for mobile
             if (window.screen.height < 800) {
@@ -530,6 +542,22 @@ function openreader(ldata, extra) {
 
 }
 
+function getSignature (data) {
+	var signedicon = '';
+	if (data.results) {
+		if (data.results.signature === true) {
+			if (data.results.verified === true) {
+				// valid signature
+				signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa oxguard_signed" aria-hidden="true" title="' + i18n.t('This Email was signed and verified') + '"/>');
+			} else {
+				// invalid signature
+				$('<i class="oxguard_icon_fa_alert fa-pencil-square fa oxguard_signed" aria-hidden="true" title="' + i18n.t('This Email was signed and failed verification') + '"/>');
+			}
+		}
+	}
+	return (signedicon);
+}
+
 function fail(alerttype)
 {
     if (alerttype === undefined) {
@@ -544,7 +572,7 @@ function fail(alerttype)
 }
 
 function replace_content_id (content, data, item) {
-    content = content.replace(/cid:[^@]+@GUARD/, function (c) {
+    content = content.replace(/cid:[^@]+@GUARD/g, function (c) {
         var params = '&email=' + item +
         '&session=' + sessionID +
         "&userid=" + userid +
@@ -552,13 +580,21 @@ function replace_content_id (content, data, item) {
         '&auth=' + encodeURIComponent(auth) +
         '&lang=' + language +
         '&content_id=' + encodeURIComponent(c.substring(4));
-        var link = root + 'oxguard/guest/?action=getattachcid' + params;
+        var link = getFullRoot() + 'oxguard/guest?action=getattachcid' + params;
 
         return (link);
     });
     return (content);
 }
 
+function getFullRoot () {
+	// If root already has domain, just return
+	if (root.indexOf('http') > -1) {
+		return root;
+	}
+	return 'https://' + document.domain + '/' + root;
+}
+
 // Get base url
 function getURLParameter(name) {
     return decodeURIComponent((new RegExp('[?|&]' + name + '=' + '([^&;]+?)(&|#|;|$)').exec(location.search)||[,""])[1].replace(/\+/g, '%20'))||null
@@ -889,25 +925,25 @@ function sendreply(data, all) {
 
 }
 
-function reply(data) {
-    initReply(data, false);
+function reply(data, itemid) {
+    initReply(data, false, itemid);
     $('#rto').html('<span>' + prepHTML(getFrom(data)) + '</span>').show();
 }
 
-function replyall(data) {
-    initReply (data, true);
+function replyall(data, itemid) {
+    initReply (data, true, itemid);
     var replydata = getReplyData (data);
     $('#rto').html('<span>' + prepHTML(getReplyAllTo(replydata)) + '</span>').show();
 }
 
-function initReply (data, replyall) {
+function initReply (data, replyall, itemid) {
     $('[name="format"][value="html"]').prop("checked", true);
     $('.plaintexteditor').val('');
     attachlist = [];
     drawAttachments();
     $('#rsubject').text(i18n.t("re") + ': ' + data.subject);
     var bm = tinyMCE.activeEditor.selection.getBookmark();
-    tinyMCE.activeEditor.setContent(formatReply(data));
+    tinyMCE.activeEditor.setContent(replace_content_id(formatReply(data), data, itemid));
     tinyMCE.activeEditor.selection.moveToBookmark(bm);
     tinyMCE.activeEditor.focus();
     view('replydiv');
@@ -1251,7 +1287,7 @@ function downloadPGPPublic () {
 }
 
 function downloadPGPPrivate () {
-    var params = '&id=' + userid + '&cid=' + cid + '&auth=' + encodeURIComponent(auth) + '&guest=true';
+    var params = '&id=' + userid + '&cid=' + cid + '&auth=' + encodeURIComponent(auth) + '&guest=true&both=true';
     var link = root + '/oxguard/pgp/private.asc?action=getprivkeybyid' + params;
     window.open(link, '_blank');
 }
